==> nbcc_loading-0.0.1.tar.gz: nbcc_loading-0.0.1/README.md <==
<!--- Heading --->
<div align="center">
  <h1>NBCC Loading</h1>
  <p>
    Library to obtain NBCC Loadings
  </p>
<h4>
    <a href="https://github.com/rpakishore/nbcc-loading/">View Demo</a>
  <span> · </span>
    <a href="https://github.com/rpakishore/nbcc-loading">Documentation</a>
  <span> · </span>
    <a href="https://github.com/rpakishore/nbcc-loading/issues/">Report Bug</a>
  <span> · </span>
    <a href="https://github.com/rpakishore/nbcc-loading/issues/">Request Feature</a>
  </h4>
</div>
<br />

[![tests](https://github.com/rpakishore/nbcc-loading/actions/workflows/test.yml/badge.svg)]
![GitHub commit activity](https://img.shields.io/github/commit-activity/m/rpakishore/nbcc-loading)
![GitHub last commit](https://img.shields.io/github/last-commit/rpakishore/nbcc-loading)
<!-- Table of Contents -->
<h2>Table of Contents</h2>

- [1. About the Project](#1-about-the-project)
- [2. Getting Started](#2-getting-started)
  - [2.1. Prerequisites](#21-prerequisites)
  - [2.2. Dependencies](#22-dependencies)
  - [2.3. Installation](#23-installation)
- [3. Usage](#3-usage)
- [4. Roadmap](#4-roadmap)
- [5. License](#5-license)
- [6. Contact](#6-contact)
- [7. Acknowledgements](#7-acknowledgements)

<!-- About the Project -->
## 1. About the Project

A library to supply NBCC loadings, to be incorporated into other calculations

<!-- Getting Started -->
## 2. Getting Started

<!-- Prerequisites -->
### 2.1. Prerequisites

### 2.2. Dependencies

The repo comes pre-compiled with all dependencies.

<!-- Installation -->
### 2.3. Installation

Install from pypi

```bash
python -m venv .venv

.venv\Scripts\activate

pip install nbcc_loading
```
<!-- Usage -->
## 3. Usage

```python

```

<!-- Roadmap -->
## 4. Roadmap

- [ ] Snow Loadings
  - [x] NBCC 2020
  - [ ] NBCC 2015
  - [ ] NBCC 2010
- [ ] Wind Loadings
  - [x] NBCC 2020
  - [ ] NBCC 2015
  - [ ] NBCC 2010
- [ ] Seismic Loadings
  - [ ] NBCC 2020
  - [ ] NBCC 2015
  - [ ] NBCC 2010

<!-- License -->
## 5. License

See `LICENSE.txt` for more information.

<!-- Contact -->
## 6. Contact

Arun Kishore - [@rpakishore](mailto:pypi@rpakishore.co.in)

Project Link: [https://github.com/rpakishore/ak-docx](https://github.com/rpakishore/nbcc-loading)

<!-- Acknowledgments -->
## 7. Acknowledgements

- [Awesome README Template](https://github.com/Louis3797/awesome-readme-template/blob/main/README-WITHOUT-EMOJI.md)
- [Banner Maker](https://banner.godori.dev/)
- [Shields.io](https://shields.io/)
- [Carbon](https://carbon.now.sh/)

==> nbcc_loading-0.0.2.tar.gz: nbcc_loading-0.0.2/README.md <==
<!--- Heading --->
<div align="center">
  <h1>NBCC Loadings</h1>
  <p>
    Library to obtain NBCC Loadings
  </p>
<h4>
    <a href="https://github.com/rpakishore/nbcc-loadings/">View Demo</a>
  <span> · </span>
    <a href="https://github.com/rpakishore/nbcc-loadings">Documentation</a>
  <span> · </span>
    <a href="https://github.com/rpakishore/nbcc-loadings/issues/">Report Bug</a>
  <span> · </span>
    <a href="https://github.com/rpakishore/nbcc-loadings/issues/">Request Feature</a>
  </h4>
</div>
<br />

[![tests](https://github.com/rpakishore/nbcc-loadings/actions/workflows/test.yml/badge.svg)](https://github.com/rpakishore/nbcc-loadings/actions/workflows/test.yml)
![GitHub commit activity](https://img.shields.io/github/commit-activity/m/rpakishore/nbcc-loadings)
![GitHub last commit](https://img.shields.io/github/last-commit/rpakishore/nbcc-loadings)

![PyPI - Format](https://img.shields.io/pypi/format/nbcc_loading) ![PyPI - Python Version](https://img.shields.io/pypi/pyversions/nbcc_loading)

<!-- Table of Contents -->
<h2>Table of Contents</h2>

- [1. About the Project](#1-about-the-project)
- [2. Getting Started](#2-getting-started)
  - [2.1. Prerequisites](#21-prerequisites)
  - [2.2. Dependencies](#22-dependencies)
  - [2.3. Installation](#23-installation)
- [3. Usage](#3-usage)
- [4. Roadmap](#4-roadmap)
- [5. License](#5-license)
- [6. Contact](#6-contact)
- [7. Acknowledgements](#7-acknowledgements)

<!-- About the Project -->
## 1. About the Project

A library to supply NBCC loadings, to be incorporated into other calculations

<!-- Getting Started -->
## 2. Getting Started

<!-- Prerequisites -->
### 2.1. Prerequisites

### 2.2. Dependencies

The repo comes pre-compiled with all dependencies.

<!-- Installation -->
### 2.3. Installation

Install from pypi

```bash
python -m venv .venv

.venv\Scripts\activate

pip install nbcc_loading
```
<!-- Usage -->
## 3. Usage

```python

```

<!-- Roadmap -->
## 4. Roadmap

- [ ] Snow Loadings
  - [x] NBCC 2020
  - [ ] NBCC 2015
  - [ ] NBCC 2010
- [ ] Wind Loadings
  - [x] NBCC 2020
  - [ ] NBCC 2015
  - [ ] NBCC 2010
- [ ] Seismic Loadings
  - [ ] NBCC 2020
  - [ ] NBCC 2015
  - [ ] NBCC 2010

<!-- License -->
## 5. License

See `LICENSE.txt` for more information.

<!-- Contact -->
## 6. Contact

Arun Kishore - [@rpakishore](mailto:pypi@rpakishore.co.in)

Project Link: [https://github.com/rpakishore/nbcc-loadings](https://github.com/rpakishore/nbcc-loadings)

<!-- Acknowledgments -->
## 7. Acknowledgements

- [Awesome README Template](https://github.com/Louis3797/awesome-readme-template/blob/main/README-WITHOUT-EMOJI.md)
- [Banner Maker](https://banner.godori.dev/)
- [Shields.io](https://shields.io/)
- [Carbon](https://carbon.now.sh/)
